@@ -26,9 +26,10 @@ extern kmp_bootstrap_lock_t __kmp_stdio_lock; /* Control stdio functions */
 extern kmp_bootstrap_lock_t
     __kmp_console_lock; /* Control console initialization */
 
-extern void __kmp_vprintf(enum kmp_io __kmp_io, char const *format, va_list ap);
+extern void __kmp_vprintf(enum kmp_io stream, char const *format, va_list ap);
 extern void __kmp_printf(char const *format, ...);
 extern void __kmp_printf_no_lock(char const *format, ...);
+extern void __kmp_fprintf(enum kmp_io stream, char const *format, ...);
 extern void __kmp_close_console(void);
 
 #ifdef __cplusplus
